MODULE par_trc
   !!======================================================================
   !!                        ***  par_trc  ***
   !! TOP :   set the passive tracers parameters
   !!======================================================================
   !! History :    -   !  1996-01  (M. Levy)  original code
   !!              -   !  1999-07  (M. Levy)  for LOBSTER1 or NPZD model
   !!              -   !  2000-04  (O. Aumont, M.A. Foujols)  HAMOCC3 and P3ZD
   !!             1.0  !  2004-03  (C. Ethe) Free form and module
   !!             2.0  !  2007-12  (C. Ethe, G. Madec)  revised architecture
   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
   USE par_kind          ! kind parameters
   !
   USE par_lobster   ! LOBSTER model
   USE par_pisces    ! PISCES  model
   USE par_c14b      ! C14 bomb tracer
   USE par_cfc       ! CFC 11 and 12 tracers
   USE par_my_trc    ! user defined passive tracers

   IMPLICIT NONE
   PUBLIC

   ! Passive tracers : Total size
   ! ---------------               ! total number of passive tracers, of 2d and 3d output and trend arrays
   INTEGER, PUBLIC, PARAMETER ::   jptra    =  jp_lobster    + jp_pisces     + jp_cfc     + jp_my_trc
   INTEGER, PUBLIC, PARAMETER ::   jpdia2d  =  jp_lobster_2d + jp_pisces_2d  + jp_cfc_2d  + jp_my_trc_2d
   INTEGER, PUBLIC, PARAMETER ::   jpdia3d  =  jp_lobster_3d + jp_pisces_3d  + jp_cfc_3d  + jp_my_trc_3d
   !                     ! total number of sms diagnostic arrays
   INTEGER, PUBLIC, PARAMETER ::   jpdiabio = jp_lobster_trd + jp_pisces_trd + jp_cfc_trd + jp_my_trc_trd
   
   !  1D configuration ("key_c1d")
   ! -----------------
# if defined key_c1d
   LOGICAL, PUBLIC, PARAMETER ::   lk_trc_c1d   = .TRUE.   !: 1D pass. tracer configuration flag
# else   
   LOGICAL, PUBLIC, PARAMETER ::   lk_trc_c1d   = .FALSE.  !: 1D pass. tracer configuration flag
# endif
   ! Passive tracers : size for TRP trends diagnotics (used if 'key_trc_diatrd' defined)
# if defined key_trc_diatrd
   ! Passive tracers : size for TRP trends diagnotics (used if 'key_trc_diatrd' defined)
   INTEGER, PARAMETER ::   jptrc_xad     =  1   !: x- horizontal advection
   INTEGER, PARAMETER ::   jptrc_yad     =  2   !: y- horizontal advection
   INTEGER, PARAMETER ::   jptrc_zad     =  3   !: z- vertical   advection
   INTEGER, PARAMETER ::   jptrc_xdf     =  4   !: lateral       diffusion
   INTEGER, PARAMETER ::   jptrc_ydf     =  5   !: lateral       diffusion
   INTEGER, PARAMETER ::   jptrc_zdf     =  6   !: vertical diffusion (Kz)
   INTEGER, PARAMETER ::   jptrc_sbc     =  7   !: surface boundary condition
#if ! defined key_trcldf_eiv && ! defined key_trcdmp
   INTEGER, PARAMETER ::   jpdiatrc      =  7  !: trends: 3*(advection + diffusion       ) + sbc
#endif
#if defined key_trcldf_eiv && defined key_trcdmp
   INTEGER, PARAMETER ::   jptrc_xei     =  8   !: x- horiz. EIV advection
   INTEGER, PARAMETER ::   jptrc_yei     =  9   !: y- horiz. EIV advection
   INTEGER, PARAMETER ::   jptrc_zei     = 10   !: z- vert.  EIV advection
   INTEGER, PARAMETER ::   jptrc_dmp     = 11   !: damping
   INTEGER, PARAMETER ::   jpdiatrc      = 11   !: trends: 3*(advection + diffusion + eiv ) + sbc + damping
#endif
#if defined key_trcldf_eiv && ! defined key_trcdmp
   INTEGER, PARAMETER ::   jptrc_xei     =  8   !: x- horiz. EIV advection
   INTEGER, PARAMETER ::   jptrc_yei     =  9   !: y- horiz. EIV advection
   INTEGER, PARAMETER ::   jptrc_zei     = 10   !: z- vert.  EIV advection
   INTEGER, PARAMETER ::   jpdiatrc      = 10   !: trends: 3*(advection + diffusion + eiv ) + sbc 
#endif
#if ! defined key_trcldf_eiv && defined key_trcdmp
   INTEGER, PARAMETER ::   jptrc_dmp     =  8   !: damping
   INTEGER, PARAMETER ::   jpdiatrc      =  8   !: trends: 3*(advection + diffusion       ) + sbc + damping
#endif
#endif

   REAL(wp), PUBLIC  :: rtrn  = 1.e-15      !: truncation value     
   !!======================================================================
END MODULE par_trc
